@define-color caja_sidebar_bg #505050;
@define-color caja_sidebar_fg #fff;
@define-color caja_sidebar_selected_fg #fff;

/****************
 * Caja desktop *
 ****************/

.caja-canvas-item {
    border-radius: 3px;
}

.caja-desktop.caja-canvas-item {
    color: @desktop_item_fg;
    text-shadow: 1px 1px @desktop_item_text_shadow;
}

.caja-desktop.caja-canvas-item:selected {
    background-color: alpha(@theme_selected_bg_color, 0.8);
    background-image: none;
    color: @theme_selected_fg_color;
    text-shadow: none;
}

/********
 * Caja *
 ********/

/* caja sidebar */
CajaWindow FMTreeView .view,
CajaWindow CajaNotesViewer .view,
CajaWindow CajaPlacesSidebar .view,
CajaWindow CajaHistorySidebar .view,
CajaWindow CajaInformationPanel GtkVBox,
CajaWindow CajaEmblemSidebar GtkViewport {
    background-color: @caja_sidebar_bg;
    color: @caja_sidebar_fg;
    border-width: 0px;
}

/****************
 * Mate-Panel *
 ****************/

mintmenu:selected GtkBox{
    background-color: @theme_selected_bg_color;
}

/*Wncklist */
WnckTasklist .button.flat {
    margin: 2px;
    padding: 0px 3px 0px 3px;
    border-style: solid;
    border-width: 2px;
    border-radius: 3px;
    border-color: transparent;
    border-image: -gtk-scaled(url("../borders/button/button.png"), url("../borders/button/button@2.png")) 4 / 4px stretch;
    box-shadow: inset 0 1px alpha(white, 1.0),
                inset 1px 0 alpha(white, 0.5),
                inset -1px 0 alpha(white, 0.5),
                inset 0 -1px alpha(white, 0.1);
    background-color: transparent;
    background-image: linear-gradient(to bottom,
                            @button_bg_a,
                            @button_bg_b);
}

WnckTasklist .button.flat:hover {
    margin: 2px;
    padding: 0px 3px 0px 3px;
    border-style: solid;
    border-width: 2px;
    border-radius: 3px;
    border-color: transparent;
    border-image: -gtk-scaled(url("../borders/button/button.png"), url("../borders/button/button@2.png")) 4 / 4px stretch;
    box-shadow: inset 0 1px alpha(white, 1.0),
                inset 1px 0 alpha(white, 0.5),
                inset -1px 0 alpha(white, 0.5),
                inset 0 -1px alpha(white, 0.1);
    background-color: transparent;
    background-image: linear-gradient(to bottom,
                            shade(@button_bg_a, 1.1),
                            shade(@button_bg_b, 1.1));
}

WnckTasklist .button.flat:checked:hover,
WnckTasklist .button.flat:checked,
WnckTasklist .button.flat:active:hover,
WnckTasklist .button.flat:active {
    margin: 2px;
    padding: 0px 3px 0px 3px;
    border-style: solid;
    border-width: 2px;
    border-radius: 3px;
    border-color: transparent;
    border-image: -gtk-scaled(url("../borders/button/button-active.png"), url("../borders/button/button-active@2.png")) 4 / 4px stretch;
    box-shadow: inset 0 1px alpha(black, 0.1),
                inset 1px 0 alpha(black, 0.08),
                inset -1px 0 alpha(black, 0.08),
                inset 0 -1px alpha(black, 0.06);
    background-image: linear-gradient(to bottom,
                            shade(@button_bg_a, 0.7),
                            shade(@button_bg_a, 0.7));
}

MatePanelAppletFrameDBus PanelSeparator,
PanelSeparator {
    border-width: 0;
    background-image: url("../assets/separator-vertical.svg");
    background-repeat: no-repeat;
    background-position: center;
    color: transparent;
    text-shadow: none;
}
